@@ -31,13 +31,7 @@ sub attr {
     return unless $class && $attrs;
 
     # Check arguments
-    my $args;
-    if (exists $_[1]) {
-        my %args = (@_);
-        $args = \%args;
-    }
-    else { $args = $_[0] }
-    $args ||= {};
+    my $args = exists $_[1] ? {@_} : ($_[0] || {});
 
     my $chained = exists $args->{chained} ? delete $args->{chained} : 1;
     my $default = delete $args->{default};
@@ -179,10 +173,6 @@ For debugging you can set the C<MOJO_BASE_DEBUG> environment variable.
     my $instance = BaseSubClass->new(name => 'value');
     my $instance = BaseSubClass->new({name => 'value'});
 
-This class provides a standard object constructor.
-You can pass arguments to it either as a hash or as a hashref, and they will
-be set in the object's internal hash reference.
-
 =head2 C<attr>
 
     __PACKAGE__->attr('name');
@@ -195,11 +185,6 @@ be set in the object's internal hash reference.
         default => 'foo'}
     );
 
-The C<attr> method generates one or more accessors, depending on the number
-of arguments, which work as both getters and setters.
-You can modify the accessor behavior by passing arguments to C<attr> either
-as a hash or a hashref.
-
 Currently there are three options supported.
 
     chained: Whenever you call an attribute with arguments the instance
