@@ -17,12 +17,12 @@ use Mojo::Headers;
 
 use constant MAX_MEMORY_SIZE => $ENV{MOJO_MAX_MEMORY_SIZE} || 10240;
 
-__PACKAGE__->attr(
-    [qw/buffer filter_buffer/] => (default => sub { Mojo::Buffer->new }));
+__PACKAGE__->attr([qw/buffer filter_buffer/],
+    default => sub { Mojo::Buffer->new });
 __PACKAGE__->attr([qw/body_cb filter builder_progress_cb/]);
-__PACKAGE__->attr(file    => (default => sub { Mojo::File::Memory->new }));
-__PACKAGE__->attr(headers => (default => sub { Mojo::Headers->new }));
-__PACKAGE__->attr([qw/raw_header_length relaxed/] => (default => 0));
+__PACKAGE__->attr('file',    default => sub { Mojo::File::Memory->new });
+__PACKAGE__->attr('headers', default => sub { Mojo::Headers->new });
+__PACKAGE__->attr([qw/raw_header_length relaxed/], default => 0);
 
 sub build_body {
     my $self = shift;
@@ -100,7 +100,7 @@ sub get_header_chunk {
 sub has_leftovers {
     my $self = shift;
     return 1 if $self->buffer->length || $self->filter_buffer->length;
-    return 0;
+    return;
 }
 
 sub header_length { length shift->build_headers }
