@@ -14,7 +14,7 @@ use Carp 'croak';
 use File::Copy ();
 use File::Spec;
 use IO::File;
-use Mojo::ByteStream;
+use Mojo::ByteStream 'b';
 
 use constant TMPDIR => $ENV{MOJO_TMPDIR} || File::Spec->tmpdir;
 
@@ -37,7 +37,7 @@ __PACKAGE__->attr(
 
             # Open
             $handle->open("$mode $file")
-              or die qq/Can't open file "$file": $!/;
+              or croak qq/Can't open file "$file": $!/;
             return $handle;
         }
 
@@ -45,7 +45,7 @@ __PACKAGE__->attr(
         my $base = File::Spec->catfile(TMPDIR, 'mojo.tmp');
         $file = $base;
         while (-e $file) {
-            my $sum = Mojo::ByteStream->new(time . rand(999999999))->md5_sum;
+            my $sum = b(time . rand(999999999))->md5_sum;
             $file = "$base.$sum";
         }
 
@@ -53,7 +53,7 @@ __PACKAGE__->attr(
         $self->cleanup(1);
 
         # Open for read/write access
-        $handle->open("+> $file") or die qq/Can't open file "$file": $!/;
+        $handle->open("+> $file") or croak qq/Can't open file "$file": $!/;
         return $handle;
     }
 );
@@ -73,7 +73,7 @@ sub new {
 
 sub add_chunk {
     my $self = shift;
-    my $chunk = join '', @_ if @_;
+    my $chunk = join '', @_;
 
     # Shortcut
     return unless $chunk;
@@ -108,7 +108,7 @@ sub contains {
         substr $window, 0, $read, '';
     }
 
-    return 0;
+    return;
 }
 
 sub copy_to {
@@ -196,6 +196,8 @@ L<Mojo::File> is a container for files.
 
 =head1 ATTRIBUTES
 
+L<Mojo::File> implements the following attributes.
+
 =head2 C<cleanup>
 
     my $cleanup = $file->cleanup;
@@ -206,10 +208,6 @@ L<Mojo::File> is a container for files.
     my $handle = $file->handle;
     $file      = $file->handle(IO::File->new);
 
-Returns a L<IO::File> object representing a file upload if called without
-arguments.
-Returns the invocant if called with arguments.
-
 =head2 C<path>
 
     my $path = $file->path;
@@ -236,8 +234,6 @@ following new ones.
 
     $file = $file->copy_to('/foo/bar/baz.txt');
 
-Copies the uploaded file contents to the given path and returns the invocant.
-
 =head2 C<get_chunk>
 
     my $chunk = $file->get_chunk($offset);
@@ -250,12 +246,8 @@ Copies the uploaded file contents to the given path and returns the invocant.
 
     $file = $file->move_to('/foo/bar/baz.txt');
 
-Moves the uploaded file contents to the given path and returns the invocant.
-
 =head2 C<slurp>
 
     my $string = $file->slurp;
 
-Returns the entire file content as a string.
-
 =cut
