@@ -9,15 +9,30 @@ use base 'Mojo::Script';
 
 use Mojo::Server::CGI;
 
-__PACKAGE__->attr(description => (default => <<'EOF'));
-* Start the cgi script. *
-Takes no options.
-    cgi
+use Getopt::Long 'GetOptionsFromArray';
+
+__PACKAGE__->attr('description', default => <<'EOF');
+Start application with CGI backend.
+EOF
+__PACKAGE__->attr('usage', default => <<"EOF");
+usage: $0 cgi [OPTIONS]
+
+These options are available:
+  --nph    Enable non-parsed-header mode.
 EOF
 
 # Hi, Super Nintendo Chalmers!
 sub run {
-    Mojo::Server::CGI->new->run;
+    my $self = shift;
+    my $cgi  = Mojo::Server::CGI->new;
+
+    # Options
+    my @options = @_ ? @_ : @ARGV;
+    GetOptionsFromArray(\@options, 'nph' => sub { $cgi->nph(1) });
+
+    # Run
+    $cgi->run;
+
     return shift;
 }
 
@@ -49,6 +64,11 @@ implements the following new ones.
     my $description = $cgi->description;
     $cgi            = $cgi->description('Foo!');
 
+=head2 C<usage>
+
+    my $usage = $cgi->usage;
+    $cgi      = $cgi->usage('Foo!');
+
 =head1 METHODS
 
 L<Mojo::Script::Cgi> inherits all methods from L<Mojo::Script> and implements
