@@ -8,7 +8,7 @@ use warnings;
 use base 'Mojo::Base';
 use overload '""' => sub { shift->to_string }, fallback => 1;
 
-use Mojo::ByteStream;
+use Mojo::ByteStream 'b';
 use Mojo::Parameters;
 use Mojo::Path;
 use Socket;
@@ -82,8 +82,7 @@ sub authority {
     }
 
     # *( unreserved / pct-encoded / sub-delims )
-    my $host =
-      Mojo::ByteStream->new($self->host)->url_escape("$UNRESERVED$SUBDELIM");
+    my $host     = b($self->host)->url_escape("$UNRESERVED$SUBDELIM");
     my $port     = $self->port;
     my $userinfo = $self->userinfo;
 
@@ -111,7 +110,7 @@ sub clone {
 sub is_abs {
     my $self = shift;
     return 1 if $self->scheme && $self->authority;
-    return 0;
+    return;
 }
 
 sub parse {
@@ -228,8 +227,7 @@ sub to_string {
     my $query     = $self->query;
 
     # *( pchar / "/" / "?" )
-    my $fragment =
-      Mojo::ByteStream->new($self->fragment)->url_escape("$PCHAR\/\?");
+    my $fragment = b($self->fragment)->url_escape("$PCHAR\/\?");
 
     # Format
     my $url = '';
@@ -255,20 +253,15 @@ sub userinfo {
             $password = $2;
         }
 
-        $self->user(Mojo::ByteStream->new($user)->url_unescape->to_string);
-        $self->password(
-            Mojo::ByteStream->new($password)->url_unescape->to_string);
+        $self->user(b($user)->url_unescape->to_string);
+        $self->password(b($password)->url_unescape->to_string);
 
         return $self;
     }
 
     # *( unreserved / pct-encoded / sub-delims / ":" )
-    my $user =
-      Mojo::ByteStream->new($self->user)
-      ->url_escape("$UNRESERVED$SUBDELIM\:");
-    my $password =
-      Mojo::ByteStream->new($self->password)
-      ->url_escape("$UNRESERVED$SUBDELIM\:");
+    my $user     = b($self->user)->url_escape("$UNRESERVED$SUBDELIM\:");
+    my $password = b($self->password)->url_escape("$UNRESERVED$SUBDELIM\:");
 
     # Format
     return $user ? "$user:$password" : undef;
@@ -316,6 +309,8 @@ L<Mojo::URL> implements a subset of RFC 3986 for Uniform Resource Locators.
 
 =head1 ATTRIBUTES
 
+L<Mojo::URL> implements the following attributes.
+
 =head2 C<authority>
 
     my $authority = $url->autority;
@@ -361,10 +356,6 @@ L<Mojo::URL> implements a subset of RFC 3986 for Uniform Resource Locators.
     my $userinfo = $url->userinfo;
     $url         = $url->userinfo('root:pass%3Bw0rd');
 
-Returns the userinfo part of the URL if called without arguments.
-Returns the invocant if called with arguments.
-Expects a string containing user credentials.
-
 =head1 METHODS
 
 L<Mojo::URL> inherits all methods from L<Mojo::Base> and implements the
