@@ -11,20 +11,27 @@ use Mojo::URL;
 
 __PACKAGE__->attr('captures', default => sub { {} });
 __PACKAGE__->attr('endpoint');
-__PACKAGE__->attr('path',  default => sub {'/'});
-__PACKAGE__->attr('stack', default => sub { [] });
+__PACKAGE__->attr('method', default => sub {'get'});
+__PACKAGE__->attr('path',   default => sub {'/'});
+__PACKAGE__->attr('stack',  default => sub { [] });
 
 # I'm Bender, baby, please insert liquor!
 sub new {
     my $self = shift->SUPER::new();
-    $self->path($_[0]);
+
+    # Method and path
+    if ($_[1]) { $self->method($_[0])->path($_[1]) }
+
+    # Path only
+    else { $self->path($_[0]) }
+
     return $self;
 }
 
 sub is_path_empty {
     my $self = shift;
     return 1 if !length $self->path || $self->path eq '/';
-    return 0;
+    return;
 }
 
 sub url_for {
@@ -123,6 +130,8 @@ L<MojoX::Routes::Match> is a match container.
 
 =head2 ATTRIBUTES
 
+L<MojoX::Routes::Match> implements the following attributes.
+
 =head2 C<captures>
 
     my $captures = $match->captures;
@@ -133,6 +142,11 @@ L<MojoX::Routes::Match> is a match container.
     my $endpoint = $match->endpoint;
     $match       = $match->endpoint(1);
 
+=head2 C<method>
+
+    my $method = $match->method;
+    $match     = $match->method('get');
+
 =head2 C<path>
 
     my $path = $match->path;
