@@ -80,7 +80,7 @@ sub start_daemon_ok {
     return $tb->ok(0, $desc) unless $path;
 
     # Prepare command
-    $self->command(qq/$^X "$path" daemon $port/);
+    $self->command(qq/$^X "$path" daemon --port $port/);
 
     return $self->start_server_ok($desc);
 }
@@ -98,7 +98,7 @@ sub start_daemon_prefork_ok {
     return $tb->ok(0, $desc) unless $path;
 
     # Prepare command
-    $self->command(qq/$^X "$path" daemon_prefork $port/);
+    $self->command(qq/$^X "$path" daemon_prefork --port $port/);
 
     return $self->start_server_ok($desc);
 }
